@@ -27,10 +27,13 @@ from codeaudit.totals import get_statistics , overview_count , overview_per_file
 from codeaudit.checkmodules import get_imported_modules , check_module_vulnerability , get_all_modules , get_imported_modules_by_file
 from codeaudit.htmlhelpfunctions import dict_to_html , json_to_html , dict_list_to_html_table
 from codeaudit import __version__
+from codeaudit.pypi_package_scan import get_pypi_download_info , get_package_source
+
+from codeaudit.api_interfaces import filescan
 
 from importlib.resources import files
 
-DISCLAIMER_TEXT = "<p><b>Disclaimer:</b><i>This SAST tool 'codeaudit' provides a powerful automatic security analysis for Python source code. However it's not a substitute for human review in combination with business knowledge. <b>Undetected vulnerabilities may still exist</b>. There is and will never be a single security tool that gives 100% automatic guarantees. By reporting any issues you find, you contribute to a better tool for everyone.</i></p>"
+DISCLAIMER_TEXT = "<p><b>Disclaimer:</b><i>This SAST tool <b>Python Code Audit</b> provides a powerful, automatic security analysis for Python source code. However, it's not a substitute for human review in combination with business knowledge. Undetected vulnerabilities may still exist. <b>There is, and will never be, a single security tool that gives 100% automatic guarantees</b>. By reporting any issues you find, you contribute to a better tool for everyone.</i>"
 
 
 SIMPLE_CSS_FILE = files('codeaudit') / 'simple.css'
@@ -38,24 +41,76 @@ SIMPLE_CSS_FILE = files('codeaudit') / 'simple.css'
 DEFAULT_OUTPUT_FILE = 'codeaudit-report.html'
 
 def overview_report(directory, filename=DEFAULT_OUTPUT_FILE):
-    """Reports Complexity and statistics per Python file from a directory.
+    """Generates an overview report of code complexity and security indicators.
+
+    This function analyzes a Python project to produce a high-level overview of
+    complexity and security-related metrics. The input may be either:
+
+    - A local directory containing Python source files
+    - The name of a package hosted on PyPI.org
+
+    For PyPI packages, the source distribution (sdist) is downloaded,
+    extracted to a temporary directory, scanned, and removed after the report
+    is generated.
+
+    The report includes summary statistics, security risk indicators based on
+    complexity and total lines of code, a list of discovered modules, per-file
+    metrics, and a visual overview. Results are written to a static HTML file.
     
-    Parameters:
-        directory (str): Path to the directory to scan.
-        filename (str): Output filename for the HTML report.
+    Examples:
+        Generate an overview report for a local project directory::
+
+            codeaudit overview /projects/mycolleaguesproject
+
+        Generate an overview report for a PyPI package::
+
+            codeaudit overview linkaudit #A nice project on PyPI.org
+
+            codeaudit overview pydantic  #A complex project on PyPI.org from a security perspective?
+
+    Args:
+        directory (str): Path to a local directory containing Python source files
+            or the name of a package available on PyPI.org.
+        filename (str, optional): Name (and optional path) of the HTML file to
+            write the overview report to. The filename should use the ``.html``
+            extension. Defaults to ``DEFAULT_OUTPUT_FILE``.
+
+    Returns:
+        None. The function writes a static HTML overview report to disk.
+
+    Raises:
+        SystemExit: If the provided path is not a directory, contains no Python
+            files, or is neither a valid local directory nor a valid PyPI
+            package name.    
     """
-    if not os.path.exists(directory):
-        print(f"ERROR: Directory '{directory}' does not exist.")
-        print(f"This function only works for directories which contains one or more Python source code files (*.py). ")
-        exit(1)
-    if not os.path.isdir(directory):
-        print(f"ERROR: '{directory}' is not a directory (maybe you try to run it for a single file)")
-        print(f"This function only works for directories which contains one or more Python source code files (*.py). ")
-        exit(1)
-    #Check if the directory has Python files
-    if not has_python_files(directory):
-        print(f'Error: Directory path {directory} contains no Python files.')
-        exit(1)
+    clean_up = False
+    if os.path.exists(directory):
+        # Check if the path is actually a directory
+        if not os.path.isdir(directory):
+            print(f"ERROR: '{directory}' is not a directory.")
+            print("This function only works for directories containing Python files (*.py).")
+            exit(1)      
+        # Check if the directory contains any .py files
+        if not has_python_files(directory):
+            print(f"ERROR: Directory '{directory}' contains no Python files.")
+            exit(1)
+    elif get_pypi_download_info(directory):
+        # If local path doesn't exist, try to treat it as a PyPI package
+        print(f"No local directory with name:{directory} found locally. Checking if package exist on PyPI...")  
+        package_name = directory #The variable input_path is now equal to the package name
+        print(f"Package: {package_name} exist on PyPI.org!")        
+        pypi_data = get_pypi_download_info(package_name)
+        url = pypi_data['download_url']
+        release = pypi_data['release']
+        if url is not None:
+            print(f'Creating Python Code Audit overview for package:\n{url}')            
+            src_dir, tmp_handle = get_package_source(url)                    
+            directory = src_dir
+            clean_up = True            
+    else:
+        # Neither a local directory nor a valid PyPI package
+        print(f"ERROR: '{directory}' is not a local directory or a valid PyPI package.")
+        exit(1)    
     result = get_statistics(directory)
     modules = total_modules(directory)    
     df = pd.DataFrame(result)
@@ -63,7 +118,11 @@ def overview_report(directory, filename=DEFAULT_OUTPUT_FILE):
     df['External-Modules'] = modules['External-Modules']
     overview_df = overview_count(df)
     html = '<h1>' + f'Python Code Audit overview report' + '</h1><br>'
-    html += f'<p>Codeaudit overview scan of the directory:<b> {directory}</b></p>' 
+    if clean_up:
+        html += f'<p>Codeaudit overview scan of package:<b> {package_name}</b></p>' 
+        html += f'<p>Version:<b>{release}</b></p>'
+    else:
+        html += f'<p>Codeaudit overview scan of the directory:<b> {directory}</b></p>' 
     html += f'<h2>Summary</h2>'
     html += overview_df.to_html(escape=True,index=False)
     html += '<br><br>'
@@ -80,6 +139,8 @@ def overview_report(directory, filename=DEFAULT_OUTPUT_FILE):
     html += '<br>'
     ## Module overview    
     modules_discovered = get_all_modules(directory)
+    if clean_up:
+        tmp_handle.cleanup() #Clean up tmp directory if overview is created directly from PyPI package
     html += '<details>' 
     html += '<summary>Click to see all discovered modules.</summary>'         
     html+=dict_to_html(modules_discovered)
@@ -103,23 +164,54 @@ def overview_report(directory, filename=DEFAULT_OUTPUT_FILE):
         
         
 
-def scan_report(input_path , filename=DEFAULT_OUTPUT_FILE):
-    """Scans Python files or directories(packages) for vulnerabilities and reports potential issues.
-        
-    This function performs security validations on the specified file or directory, 
-    formats the results into an HTML report, and writes the output to an HTML file. 
-    
-    You can specify the name of the outputfile and directory for the generated HTML report. Make sure you chose the extension `.html` since the output file is a static html file.
+def scan_report(input_path, filename=DEFAULT_OUTPUT_FILE):
+    """Scans Python source code or PyPI packages for security weaknesses.
 
-    Parameters:
-        file_to_scan (str)      : The full path to the Python source file to be scanned.
-        filename (str, optional): The name of the HTML file to save the report to.
-                                  Defaults to `DEFAULT_OUTPUT_FILE`.
+    This function performs static application security testing (SAST) on a
+    given input, which can be:
+
+    - A local directory containing Python source code
+    - A single local Python file 
+    - A package name hosted on PyPI.org
+
+    Depending on the input type, the function analyzes the source code for
+    potential security issues, generates an HTML report summarizing the
+    findings, and writes the report to a static HTML file.
+
+    If a PyPI package name is provided, the function downloads the source
+    distribution (sdist), scans the extracted source code, and removes all
+    temporary files after the scan completes.
+
+    Example:
+        Scan a local directory and write the report to ``report.html``::
+
+            codeaudit filescan_/shitwork/custompythonmodule/ 
+
+        Scan a single Python file::
+
+            codeaudit filescan myexample.py
+
+        Scan a package hosted on PyPI::
+
+            codeaudit filescan linkaudit  #A nice project to check broken links in markdown files
+
+            codeaudit filescan requests
+
+    Args:
+        input_path (str): Path to a local Python file or directory, or the name
+            of a package available on PyPI.org.
+        filename (str, optional): Name (and optional path) of the HTML file to
+            write the scan report to. The filename should use the ``.html``
+            extension. Defaults to ``DEFAULT_OUTPUT_FILE``.
 
     Returns:
-        None - A HTML report is written as output
+        None. The function writes a static HTML security report to disk.
+
+    Raises:
+        None explicitly. Errors and invalid inputs are reported to stdout.    
     """
-      # Check if the input is a valid directory or a single valid Python file
+    # Check if the input is a valid directory or a single valid Python file 
+    # In case no local file or directory is found, check if the givin input is pypi package name
     file_path = Path(input_path)
     if file_path.is_dir():
         directory_scan_report(input_path , filename ) #create a package aka directory scan report
@@ -135,9 +227,26 @@ def scan_report(input_path , filename=DEFAULT_OUTPUT_FILE):
         html += '<br>'
         html += DISCLAIMER_TEXT
         create_htmlfile(html,filename)
+    elif get_pypi_download_info(input_path):
+        package_name = input_path #The variable input_path is now equal to the package name
+        print(f"Package: {package_name} exist on PyPI.org!")
+        print(f"Now SAST scanning package from the remote location: https://pypi.org/pypi/{package_name}")        
+        pypi_data = get_pypi_download_info(package_name)
+        url = pypi_data['download_url']
+        release = pypi_data['release']
+        if url is not None:
+            print(url)
+            print(release)
+            src_dir, tmp_handle = get_package_source(url)
+            directory_scan_report(src_dir , filename , package_name, release ) #create scan report for a package or directory
+            # Cleaning up temp directory 
+            tmp_handle.cleanup()  # deletes everything from temp directory
+        else:
+            print(f'Error:A source distribution (sdist in .tar.gz format) for package: {package_name} can not be found or does not exist on PyPi.org.\n')
+            print(f"Make a local git clone of the {package_name} using `git clone` and run `codeaudit filescan <directory-with-src-cloned-of-{package_name}>` to check for weaknesses.")
     else:
         #File is NOT a valid Python file, can not be parsed or directory is invalid.
-        print(f"Error: '{input_path}' isn't a valid Python file or directory path.")
+        print(f"Error: '{input_path}' isn't a valid Python file, directory path to a package or a package on PyPI.org.")
         
    
 
@@ -169,14 +278,14 @@ def single_file_report(filename , scan_output):
     df = df.sort_values(by="line") # sort by line number    
     html = f'<p>Number of potential security issues found: {number_of_issues}</p>'
     html += '<details>' 
-    html += '<summary>Click to see the details for found security issues.</summary>'         
+    html += '<summary>Click to view identified security weaknesses.</summary>'         
     html += df.to_html(escape=False,index=False)        
     html += '</details>'
     file_overview = overview_per_file(filename)    
     df_overview = pd.DataFrame([file_overview])
     html += '<br>'
-    html += '<details>' 
-    html += f'<summary>Click to see details for file {filename}</summary>'                 
+    html += '<details>'     
+    html += f'<summary>Click to see file details.</summary>'                 
     html += df_overview.to_html(escape=True,index=False)        
     html += '</details>'           
     #imported modules
@@ -190,7 +299,7 @@ def single_file_report(filename , scan_output):
     return html 
 
 
-def directory_scan_report(directory_to_scan , filename=DEFAULT_OUTPUT_FILE):
+def directory_scan_report(directory_to_scan , filename=DEFAULT_OUTPUT_FILE , package_name=None , release=None):
     """Reports potential security issues for all Python files found in a directory.
     
     This function performs security validations on all files found in a specified directory.
@@ -199,7 +308,7 @@ def directory_scan_report(directory_to_scan , filename=DEFAULT_OUTPUT_FILE):
     You can specify the name and directory for the generated HTML report.
 
     Parameters:
-        file_to_scan (str)      : The full path to the Python source file to be scanned.
+        directory_to_scan (str)      : The full path to the Python source files to be scanned. Can be present in temp directory.
         filename (str, optional): The name of the HTML file to save the report to.
                                   Defaults to `DEFAULT_OUTPUT_FILE`.
 
@@ -216,8 +325,13 @@ def directory_scan_report(directory_to_scan , filename=DEFAULT_OUTPUT_FILE):
     files_to_check = collect_python_source_files(directory_to_scan)
     html += '<h2>Directory scan report</h2>'         
     name_of_package = get_filename_from_path(directory_to_scan)
-    html += f'<p>Below the result of the Codeaudit scan of the package or directory:<b> {name_of_package}</b></p>' 
-    html += f'<p>Total Python files found: {len(files_to_check)}</p>'
+    if package_name is not None:
+        #Use real package name and retrieved release info
+        html += f'<p>Below the result of the Codeaudit scan of (Package name - Release):</p>'
+        html += f'<p><b> {package_name} - {release} </b></p>'
+    else:
+        html += f'<p>Below the result of the Codeaudit scan of the directory:<b> {name_of_package}</b></p>' 
+    html += f'<p>Total Python files found: <b>{len(files_to_check)}</b></p>'
     number_of_files = len(files_to_check)
     print(f'Number of files that are checked for security issues:{number_of_files}')
     printProgressBar(0, number_of_files, prefix='Progress:', suffix='Complete', length=50)    
@@ -229,7 +343,8 @@ def directory_scan_report(directory_to_scan , filename=DEFAULT_OUTPUT_FILE):
             file_report_html = single_file_report(file_to_scan , scan_output)             
             name_of_file = get_filename_from_path(file_to_scan)            
             html += f'<h3>Result for file {name_of_file}</h3>'    
-            html += '<p>' + f'Location of the file: {file_to_scan} </p>'          
+            if package_name is None:
+                html += '<p>' + f'Location of the file: {file_to_scan} </p>'          
             html += file_report_html            
         else:
             file_name_with_no_issue = get_filename_from_path(file_to_scan)
@@ -240,13 +355,44 @@ def directory_scan_report(directory_to_scan , filename=DEFAULT_OUTPUT_FILE):
     html += '<p>The Python files with no security issues <b>detected</b> by codeaudit are:<p>'        
     html += dict_list_to_html_table(collection_ok_files)     
     html += '<br>'
+    if package_name is not None:
+        html += f'<p><b>Note:</b><i>Since this check is done on a package on PyPI.org, the temporary local directories are deleted. To examine the package in detail, you should download the sources locally and run the command:<code>codeaudit filescan</code> again.</i></p>'
     html += '<p><b>Disclaimer:</b><i>Only Python source files are taken into account for this scan. Sometimes security issues are present in configuration files, like ini,yaml or json files!</i></p>'
     html += DISCLAIMER_TEXT
     create_htmlfile(html,filename)  
 
+def report_module_information(inputfile, reportname=DEFAULT_OUTPUT_FILE):
+    """Generates a vulnerability report for imported Python modules.
 
-def report_module_information(inputfile,reportname=DEFAULT_OUTPUT_FILE):
-    """Reports module vulnerability information.""" 
+    This function analyzes a single Python source file to identify imported
+    modules and checks externally imported modules against the OSV vulnerability
+    database. The results are compiled into a static HTML report.
+
+    For each detected external module, the report indicates whether known
+    vulnerability information exists and, if available, includes detailed
+    vulnerability data.
+
+    Progress information is printed to stdout while processing modules.
+
+    Example:
+        Generate a module vulnerability report for a Python file::
+
+            codeaudit modulescan mypythonfile.py 
+
+    Args:
+        inputfile (str): Path to the Python source file to analyze.
+        reportname (str, optional): Name (and optional path) of the HTML file
+            to write the module vulnerability report to. The filename should
+            use the ``.html`` extension. Defaults to ``DEFAULT_OUTPUT_FILE``.
+
+    Returns:
+        None. The function writes a static HTML report to disk.
+
+    Raises:
+        None explicitly. File reading errors or invalid input are reported
+        via standard output.
+    
+    """
     source = read_in_source_file(inputfile)
     used_modules = get_imported_modules(source)
     # Initial call to print 0% progress
@@ -393,18 +539,23 @@ def report_implemented_tests(filename=DEFAULT_OUTPUT_FILE):
     Creates an HTML report of all implemented security checks.
 
     This report provides a user-friendly overview of the static security checks 
-    currently supported by codeaudit. It is intended to make it easier to review 
+    currently supported by Python Code Audit. It is intended to make it easier to review 
     the available validations without digging through the codebase.
 
     The generated HTML includes:
     - A table of all implemented checks
     - The number of validations
-    - The version of codeaudit used
+    - The version of Python Code Audit (codeaudit) used
     - A disclaimer about version-specific reporting
 
     The report is saved to the specified filename and is formatted to be 
     embeddable in larger multi-report documents.
 
+    Help me continue developing Python Code Audit as free and open-source software.
+    Join the community to contribute to the most complete, local first , Python Security Static scanner.
+    Help!!  Join the journey, check: https://github.com/nocomplexity/codeaudit#contributing 
+    
+
     Parameters:
         filename (str): The output HTML filename. Defaults to 'codeaudit_checks.html'.
     """    
